@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ninetyfive" "20251125.2223"
+(define-package "ninetyfive" "20260213.1623"
   "NinetyFive."
   '((emacs     "26.1")
     (websocket "1.12")
     (async     "1.9.7"))
-  :url "https://github.com/ninetyfive-gg/ninetyfive.el"
-  :commit "0d673ac905c68a91dadf7e9c2ff6fa9c6402034e"
-  :revdesc "0d673ac905c6"
+  :url "https://github.com/numerataz/ninetyfive.el"
+  :commit "f2af587f97168e3544e770e74690cf0d7877c250"
+  :revdesc "f2af587f9716"
   :keywords '("convenience" "productivity"))
